@@ -1,5 +1,5 @@
 var Riot=Riot||{};
-"object"===typeof Riot&&function(){var e=window,r=document,g=e.localStorage,a=Riot.DDragon={mu:"http://ddragonqa.riotgames.com/realms/na.js",it:0,fixed:"fixed",langInterface:{ar:"ar_AR",bg:"bg_BG",cs:"cs_CZ",de:"de_DE",el:"el_GR",en:"en_US",es:"es_ES",fr:"fr_FR",hu:"hu_HU",it:"it_IT",ja:"ja_JP",ko:"ko_KR",nl:"nl_NL",pl:"pl_PL",pt:"pt_BR",ro:"ro_RO",ru:"ru_RU",th:"th_TH",tr:"tr_TR",vi:"vi_VN",zh:"zh_CN"},jsonp:function(a,b){var h=r.createElement("script");h.setAttribute("type","text/javascript");h.setAttribute("async",
+"object"===typeof Riot&&function(){var e=window,r=document,g=e.localStorage,a=Riot.DDragon={mu:"http://ddragonqa.riotgames.com/realms/na.js",it:0,fixed:"fixed",langInterface:{ar:"ar_AE",bg:"bg_BG",cs:"cs_CZ",de:"de_DE",el:"el_GR",en:"en_US",es:"es_ES",fr:"fr_FR",hu:"hu_HU",id:"id_ID",it:"it_IT",ja:"ja_JP",ko:"ko_KR",nl:"nl_NL",pl:"pl_PL",pt:"pt_BR",ro:"ro_RO",ru:"ru_RU",th:"th_TH",tr:"tr_TR",vi:"vi_VN",zh:"zh_CN"},jsonp:function(a,b){var h=r.createElement("script");h.setAttribute("type","text/javascript");h.setAttribute("async",
 "async");h.setAttribute("src",a);if("function"==typeof b)h.onload="object"===typeof e.onload&&"object"===typeof e.onreadystatechange?b:h.onreadystatechange=b;h&&r.body.appendChild(h)},xhr:{ready:!0,getHTTPObject:function(){var a=!1;if("undefined"!==typeof ActiveXObject)try{a=new ActiveXObject("Msxml2.XMLHTTP")}catch(b){try{a=new ActiveXObject("Microsoft.XMLHTTP")}catch(h){a=!1}}else if(e.XMLHttpRequest)try{a=new XMLHttpRequest}catch(d){a=!1}return a},load:function(c,b,h){if(a.xhr.ready){var d=this.init();
 if(d&&c){try{d.open("GET",c,!0)}catch(e){a.xhr.ready=!1;a.jsonp(c,h);return}d.onreadystatechange=function(){var e="";if(4===d.readyState&&a.xhr.ready)switch(d.status){case 200:case 304:if(d.responseText)e=d.responseText;b(e);break;default:a.xhr.ready=!1,a.jsonp(c,h)}};d.send(null)}}else a.jsonp(c,h)},init:function(){return this.getHTTPObject()}},app:[],addApp:function(c,b){a.app.push({app:b,ms:c||[]})},mps:{},amp:function(c,b){a.mps[c]?a.mps[c].push(b):a.mps[c]=[b]},addModelParser:function(c,b){a.amp(c,
 b)},ddf:"/js/dragonmagic.js",lsp:function(){a.rd()},fin:function(){a.fn.init()},rd:function(){var c=!1;if(a.ls)if(a.rdd=g.getItem("rg_ddragon_override"),null!==a.rdd)c=!0;else if(g.getItem("rg_ddragon_c")===a.m.dd){var b;if(b=g.getItem("rg_ddragon")){eval(b);a.fin();return}}if(!c&&(a.rdd=a.m.cdn+a.m.dd+"/js/dragonmagic.js","string"===typeof e.rg_force_ddragon))a.rdd=e.rg_force_ddragon;a.xhr.load(a.rdd,function(b){a.ls&&(g.setItem("rg_ddragon",b),g.setItem("rg_ddragon_c",a.m.dd));eval(b);a.fin()},
